@@ -3,22 +3,31 @@ import copy
 from datetime import datetime
 import warnings
 
+try:
+    from collections import Mapping
+    _HAS_ABCS = True
+except ImportError:
+    _HAS_ABCS = False
+
+
 class SchemaError(ValueError):
     """
     errors encountered in processing a schema (subclass of :class:`ValueError`)
     """
 
+
 class ValidationError(ValueError):
     """
     validation errors encountered during validation (subclass of
     :class:`ValueError`)
     """
 
+
 def _generate_datetime_validator(format_option, dateformat_string):
     def validate_format_datetime(validator, fieldname, value, format_option):
         try:
             datetime.strptime(value, dateformat_string)
-        except ValueError, e:
+        except ValueError:
             raise ValidationError(
                     "Value %(value)r of field '%(fieldname)s' is not in '%(format_option)s' format" % locals())
 
@@ -28,8 +37,9 @@ validate_format_date_time  = _generate_datetime_validator('date-time', '%Y-%m-%d
 validate_format_date       = _generate_datetime_validator('date', '%Y-%m-%d')
 validate_format_time       = _generate_datetime_validator('time', '%H:%M:%S')
 
+
 def validate_format_utc_millisec(validator, fieldname, value, format_option):
-    if not isinstance(value, (int,float)):
+    if not isinstance(value, (int, float)):
         raise ValidationError("Value %(value)r of field '%(fieldname)s' is not a number" % locals())
 
     if not value > 0:
@@ -43,13 +53,14 @@ DEFAULT_FORMAT_VALIDATORS = {
     'utc-millisec' : validate_format_utc_millisec,
 }
 
+
 class SchemaValidator(object):
     '''
     Validator largely based upon the JSON Schema proposal but useful for
     validating arbitrary python data structures.
 
     :param format_validators: optional dictionary of custom format validators
-    :param required_by_default: defaults to True, set to False to make 
+    :param required_by_default: defaults to True, set to False to make
         ``required`` schema attribute False by default.
     '''
 
@@ -76,6 +87,8 @@ class SchemaValidator(object):
         return type(val) == bool
 
     def validate_type_object(self, val):
+        if _HAS_ABCS:
+            return isinstance(val, Mapping)
         return isinstance(val, dict)
 
     def validate_type_array(self, val):
@@ -280,10 +293,10 @@ class SchemaValidator(object):
                 # NOTE: the version 3 spec is really unclear on what this means
                 # based on the meta-schema I'm assuming that it should check
                 # that if a key exists, the appropriate value exists
-                for k,v in dependencies.iteritems():
+                for k, v in dependencies.iteritems():
                     if k in x and v not in x:
                         self._error("Field '%(v)s' is required by field '%(k)s'",
-                                    None, fieldname, k=k,v=v)
+                                    None, fieldname, k=k, v=v)
             else:
                 raise SchemaError("'dependencies' must be a string, "
                                   "list of strings, or dict")
@@ -318,7 +331,6 @@ class SchemaValidator(object):
                     self._error("Value %(value)r for field '%(fieldname)s' is greater than maximum value: %(maximum)f",
                                 value, fieldname, maximum=maximum)
 
-
     def validate_maxLength(self, x, fieldname, schema, length=None):
         '''
         Validates that the value of the given field is shorter than or equal
@@ -350,12 +362,11 @@ class SchemaValidator(object):
 
         format_validator = self._format_validators.get(format_option, None)
 
-        if format_validator:
+        if format_validator and value:
             format_validator(self, fieldname, value, format_option)
 
         # TODO: warn about unsupported format ?
 
-
     def validate_pattern(self, x, fieldname, schema, pattern=None):
         '''
         Validates that the given field, if a string, matches the given
